@@ -2,6 +2,8 @@ from os import PathLike
 from pathlib import Path
 from typing import List, Dict, Optional, ClassVar
 
+from vatis.asr_commons.domain import Word
+
 
 class ReplacementMerge:
     MERGE_LEFT: ClassVar[str] = 'MERGE_LEFT'
@@ -13,11 +15,14 @@ class ReplacementMerge:
 
 class Expressions:
     DEFAULT_REPLACEMENT_MERGE: ClassVar[str] = ReplacementMerge.STANDALONE
+    DEFAULT_REPLACEMENT_ENTITY: ClassVar[str] = Word.Entity.REPLACED
 
     def __init__(self, expressions: Dict[str, List[str]] = None,
-                 replacement_merge: Dict[str, str] = None):
+                 replacement_merge: Dict[str, str] = None,
+                 replacement_entity: Dict[str, str] = None):
         self._expressions: Dict[str, List[str]] = expressions if expressions is not None else {}
         self._replacement_merge: Dict[str, str] = replacement_merge if replacement_merge is not None else {}
+        self._replacement_entity: Dict[str, str] = replacement_entity if replacement_entity is not None else {}
 
         for key, merge in self._replacement_merge.items():
             if merge is None:
@@ -27,11 +32,24 @@ class Expressions:
             if merge not in ReplacementMerge.__dict__:
                 raise ValueError(f'Bad merge option: {merge}')
 
+        for key, entity in self._replacement_entity.items():
+            if entity is None:
+                self._replacement_entity[key] = Expressions.DEFAULT_REPLACEMENT_ENTITY
+                continue
+
+            if entity not in Word.Entity.__dict__:
+                raise ValueError(f'Bad entity option: {entity}')
+
     @staticmethod
     def _parse_tsv_string(tsv_str: str) -> Dict[str, List[str]]:
         expressions: Dict[str, List[str]] = {}
 
         for line in tsv_str.split('\n'):
+            line = line.strip()
+
+            if line.startswith('#'):
+                continue
+
             tokens = line.split('\t')
             expressions[tokens[0]] = tokens[1:]
 
@@ -71,26 +89,21 @@ class Expressions:
     @staticmethod
     def from_tsv_file(tsv_file: PathLike, raise_if_not_found: bool = False) -> 'Expressions':
         tsv_file = Path(tsv_file)
-        expressions: Dict[str, List[str]] = {}
 
         if tsv_file.exists():
             with open(tsv_file, 'r') as f:
-                for line in f:
-                    line: str = line.strip()
+                lines = f.readlines()
 
-                    if not len(line) or line.startswith('#'):
-                        continue
+            tsv = ''.join(lines)
 
-                    tokens = line.split('\t')
-
-                    expressions[tokens[0]] = tokens[1:]
+            return Expressions.from_tsv_str(tsv)
         else:
             message = f'Expressions path does not exist: {str(tsv_file)}'
 
             if raise_if_not_found:
                 raise FileNotFoundError(message)
 
-        return Expressions(expressions)
+        return Expressions.empty()
 
     @staticmethod
     def empty():
