@@ -1,7 +1,7 @@
 import dataclasses
 from typing import List, Union, Dict
 
-from vatis.asr_commons.domain.expression import Expressions, ReplacementMerge
+from vatis.asr_commons.domain.expression import Expressions
 from vatis.asr_commons.json.deserialization import JSONDeserializable
 
 
@@ -10,13 +10,15 @@ class FindReplaceConfig(JSONDeserializable):
     replacement: str
     regex: List[str]
     enabled: bool = True
-    merge: str = ReplacementMerge.STANDALONE
+    merge: str = Expressions.DEFAULT_REPLACEMENT_MERGE
+    entity: str = Expressions.DEFAULT_REPLACEMENT_ENTITY
 
     def __post_init__(self):
         assert self.replacement is not None, '"replacement" must not be none'
         assert self.regex is not None, '"regex" must not be none'
         assert self.enabled is not None, '"enabled" must not be none'
         assert self.merge is not None, '"merge" must not be none'
+        assert self.entity is not None, '"entity" must not be none'
 
     @staticmethod
     def from_json(json_dict: dict):
@@ -32,6 +34,7 @@ class FindReplaceExpressions(Expressions):
     def from_find_replace_config_list(expressions: List[Union[FindReplaceConfig, dict]]) -> 'FindReplaceExpressions':
         parsed_expressions: Dict[str, List[str]] = {}
         parsed_replacement_merge: Dict[str, str] = {}
+        parsed_replacement_entity: Dict[str, str] = {}
 
         for find_replace_config in expressions:
             if isinstance(find_replace_config, FindReplaceConfig):
@@ -44,7 +47,8 @@ class FindReplaceExpressions(Expressions):
             if find_replace_config.replacement not in parsed_expressions:
                 parsed_expressions[find_replace_config.replacement] = find_replace_config.regex.copy()
                 parsed_replacement_merge[find_replace_config.replacement] = find_replace_config.merge
+                parsed_replacement_entity[find_replace_config.replacement] = find_replace_config.entity
             else:
                 raise ValueError(f'Duplicate replacement: {find_replace_config.replacement}')
 
-        return FindReplaceExpressions(parsed_expressions, parsed_replacement_merge)
+        return FindReplaceExpressions(parsed_expressions, parsed_replacement_merge, parsed_replacement_entity)
