@@ -172,6 +172,8 @@ class Word:
         LANGUAGE: ClassVar[str] = 'LANGUAGE'
         NAT_REL_POL: ClassVar[str] = 'NAT_REL_POL'
         DATETIME: ClassVar[str] = 'DATETIME'
+        DATE: ClassVar[str] = 'DATE'
+        TIME: ClassVar[str] = 'TIME'
         PERIOD: ClassVar[str] = 'PERIOD'
         QUANTITY: ClassVar[str] = 'QUANTITY'
         MONEY: ClassVar[str] = 'MONEY'
@@ -181,6 +183,9 @@ class Word:
         WORK_OF_ART: ClassVar[str] = 'WORK_OF_ART'
         EVENT: ClassVar[str] = 'EVENT'
         REPLACED: ClassVar[str] = 'REPLACED'
+        CODE: ClassVar[str] = 'CODE'
+        ELECTRONIC: ClassVar[str] = 'ELECTRONIC'
+        RANGE: ClassVar[str] = 'RANGE'
 
     def __init__(self, word: str, start_time_millis: float, end_time_millis: float, speaker: Optional[Union[str, int]] = None,
                  confidence: float = 0, entity: Optional[str] = None, entity_group_id: Optional[Union[int, str]] = None):
